@@ -440,7 +440,7 @@ fn installed_satisfies_requirement(
         // If the requirement comes from a direct URL, check by URL.
         Some(VersionOrUrl::Url(url)) => {
             if let InstalledDist::Url(installed) = &distribution {
-                if &installed.url == url.raw() {
+                if !installed.editable && &installed.url == url.raw() {
                     // If the requirement came from a local path, check freshness.
                     if let Some(archive) = (url.scheme() == "file")
                         .then(|| url.to_file_path().ok())
