@@ -1,6 +1,8 @@
 pub use dependency_mode::DependencyMode;
 pub use error::ResolveError;
+pub use exclude_newer::ExcludeNewer;
 pub use exclusions::Exclusions;
+pub use flat_index::FlatIndex;
 pub use manifest::Manifest;
 pub use options::{Options, OptionsBuilder};
 pub use preferences::{Preference, PreferenceError};
@@ -23,7 +25,9 @@ mod dependency_mode;
 mod dependency_provider;
 mod editables;
 mod error;
+mod exclude_newer;
 mod exclusions;
+mod flat_index;
 mod manifest;
 mod options;
 mod pins;
