@@ -402,19 +402,24 @@ pub(crate) async fn pip_compile(
     };
 
     // Determine any lookahead requirements.
-    let lookaheads = LookaheadResolver::new(
-        &requirements,
-        &constraints,
-        &overrides,
-        &editables,
-        &hasher,
-        &build_dispatch,
-        &client,
-        &top_level_index,
-    )
-    .with_reporter(ResolverReporter::from(printer))
-    .resolve(&markers)
-    .await?;
+    let lookaheads = match dependency_mode {
+        DependencyMode::Transitive => {
+            LookaheadResolver::new(
+                &requirements,
+                &constraints,
+                &overrides,
+                &editables,
+                &hasher,
+                &build_dispatch,
+                &client,
+                &top_level_index,
+            )
+            .with_reporter(ResolverReporter::from(printer))
+            .resolve(&markers)
+            .await?
+        }
+        DependencyMode::Direct => Vec::new(),
+    };
 
     // Create a manifest of the requirements.
     let manifest = Manifest::new(
